(use-modules
 (gnu)
 (gnu system nss)
 (gnu packages databases)
 (gnu packages xorg)
 (gnu packages ssh)
 (gnu packages emacs-xyz)
 (gnu packages lisp)
 (gnu packages shells)
 (gnu packages xdisorg)
 (gnu packages graphviz))

(use-service-modules desktop)
(use-package-modules bootloaders certs emacs ratpoison suckless wm tmux)

(operating-system
 (host-name "rekahsoft-guix")
 (timezone "America/Toronto")
 (locale "en_US.utf8")

 ;; Use the UEFI variant of GRUB with the EFI System
 ;; Partition mounted on /boot/efi.
 (bootloader (bootloader-configuration
              (bootloader grub-efi-bootloader)
              (target "/boot/efi")))

 ;; Specify a mapped device for the encrypted root partition.
 ;; The UUID is that returned by 'cryptsetup luksUUID'.
 (mapped-devices
  (list (mapped-device
	 (source (uuid "0c17f832-2afb-4441-81cd-058b7df67231"))
	 (target "root-crypt")
	 (type luks-device-mapping))))

 (file-systems (cons*
		(file-system
                 (device (uuid "8E35-3806" 'fat))
                 (mount-point "/boot/efi")
                 (type "vfat"))
                (file-system
                 (device "/dev/mapper/root-crypt")
                 (mount-point "/")
                 (type "btrfs")
		 (options "compress=lzo,subvol=@")
                 (dependencies mapped-devices))
                (file-system
                 (device "/dev/mapper/root-crypt")
                 (mount-point "/home")
                 (type "btrfs")
		 (options "compress=lzo,subvol=@home")
                 (dependencies mapped-devices))
;;                (file-system
;;                 (device "/dev/mapper/root-crypt")
;;                 (mount-point "/gnu/store")
;;                 (type "btrfs")
;;		 (options "compress=lzo,subvol=@gnu-store")
;;                 (dependencies mapped-devices))

                %base-file-systems))

 (swap-devices '("/dev/disk/by-uuid/d90e20cb-dfa2-45b2-ae26-9b04b38b07a7"))

 (users (cons (user-account
               (name "collin")
               (comment "Master User")
               (group "users")
	       (shell #~(string-append #$zsh "/bin/zsh"))
               (supplementary-groups '("wheel" "netdev"
                                       "audio" "video"))
               (home-directory "/home/collin"))
              %base-user-accounts))

  ;; Add a bunch of window managers; we can choose one at
  ;; the log-in screen with F1.
  (packages (cons* nss-certs                      ;for HTTPS access
		   openssh
		   ratpoison stumpwm emacs-exwm
		   xmonad ghc-xmonad-contrib xmobar 
		   dmenu rofi
                   xsetroot xrandr
                   recutils
		   tmux
                   emacs
		   emacs-guix graphviz
                   xterm
                   %base-packages))

 ;; Use the "desktop" services, which
 ;; include the X11 log-in service, networking with
 ;; NetworkManager, and more.
 (services (cons* %desktop-services))

 ;; Allow resolution of '.local' host names with mDNS.
 (name-service-switch %mdns-host-lookup-nss))
